==> kapow_1.5.10.orig.tar.bz2: kapow-1.5.10/translations/kapow_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue pour l&apos;application :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Fiche horaire</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom : </translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Société : </translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adresse : </translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Téléphone : </translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Télécopie : </translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Courriel : </translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Site web : </translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Faire précéder le symbole monétaire</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Taux horaire : </translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>TVA : </translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Symbole monétaire : </translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Informations sur le contact</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Données</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Page Web (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>CSV Outlook (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Exporter le rapport</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Afficher les rapports</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Créer un rapport</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Téléphone : %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Télécopie : %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Heures</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Sous-total</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>TVA</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n heure</numerusform>
            <numerusform>%n heures</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 heures</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Session en conflit avec d&apos;autres sessions. </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Ajouter une session</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Date : </translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Début : </translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Fin : </translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Tâche : </translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Modifier la session</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Task</source>
        <translation>Tâche</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Heures</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Quotidien</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Hebdomadaire</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Mensuel</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Rapport</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Réduire</translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Projet</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Ajouter</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maj+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Maj+Suppr</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Session</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Modifier</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Suppr</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Colonnes</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>Totaux &amp;décimaux</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>Mod&amp;ifiation en ligne</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Projet</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Minuteur</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Afficher tout</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Heures non-facturées uniquement</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Cette année uniquement</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Ce mois uniquement</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Cette semaine uniquement</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Session en conflit avec d&apos;autres sessions. </translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Agrandir</translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Impossible de lire les données horaires. </translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Impossible d&apos;écrire les données horaires.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Des minuteurs sont toujours en cours d&apos;exécution. Voulez-vous les arrêter et quitter ?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Programme d&apos;aide au suivi du temps passé</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Créer un rapport…</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>&amp;Afficher les rapports</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Annuler cette session ? </translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Ajouter un projet</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Nom du projet : </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>Impossible de créer l&apos;emplacement des données horaires. </translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>Impossible de déplacer l&apos;emplacement des données horaires. </translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Un projet portant le même nom existe déjà. </translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Supprimer le projet sélectionné ? </translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Supprimer la session sélectionnée ? </translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n minuteur en cours</numerusform>
            <numerusform>%n minuteurs en cours</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Pointeuse Kapow</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation>Programme de pointeuse</translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation>Stocker les paramètres au format INI dans le fichier indiqué. </translation>
    </message>
    <message>
        <source>file</source>
        <translation>fichier</translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation>Ne pas créer de sauvegarde automatique des données horaires. </translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation>Fichier à utiliser pour les données horaires.</translation>
    </message>
</context>
</TS>

==> kapow_1.6.2.orig.tar.bz2: kapow-1.6.2/translations/kapow_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue pour l&apos;application :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Fiche horaire</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom : </translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Société : </translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adresse : </translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Téléphone : </translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Télécopie : </translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Courriel : </translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Site web : </translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Faire précéder le symbole monétaire</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Taux horaire : </translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>TVA : </translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Symbole monétaire : </translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Informations sur le contact</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Données</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Page Web (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>CSV Outlook (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Exporter le rapport</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Afficher les rapports</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Créer un rapport</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Téléphone : %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Télécopie : %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Heures</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Sous-total</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>TVA</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Remove newest report?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n heure</numerusform>
            <numerusform>%n heures</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 heures</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Session en conflit avec d&apos;autres sessions. </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Ajouter une session</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Date : </translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Début : </translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Fin : </translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Tâche : </translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Modifier la session</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Task</source>
        <translation>Tâche</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Heures</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Quotidien</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Hebdomadaire</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Mensuel</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Rapport</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Réduire</translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Projet</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Ajouter</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maj+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Maj+Suppr</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Session</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Modifier</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Suppr</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Colonnes</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>Totaux &amp;décimaux</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>Mod&amp;ifiation en ligne</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Projet</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Minuteur</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Afficher tout</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Heures non-facturées uniquement</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Cette année uniquement</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Ce mois uniquement</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Cette semaine uniquement</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Session en conflit avec d&apos;autres sessions. </translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Agrandir</translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Impossible de lire les données horaires. </translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Impossible d&apos;écrire les données horaires.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Des minuteurs sont toujours en cours d&apos;exécution. Voulez-vous les arrêter et quitter ?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Programme d&apos;aide au suivi du temps passé</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Créer un rapport…</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>&amp;Afficher les rapports</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Annuler cette session ? </translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Ajouter un projet</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Nom du projet : </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>Impossible de créer l&apos;emplacement des données horaires. </translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>Impossible de déplacer l&apos;emplacement des données horaires. </translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Un projet portant le même nom existe déjà. </translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Supprimer le projet sélectionné ? </translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Supprimer la session sélectionnée ? </translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n minuteur en cours</numerusform>
            <numerusform>%n minuteurs en cours</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Pointeuse Kapow</translation>
    </message>
    <message>
        <source>&amp;Close to Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re&amp;move Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation>Programme de pointeuse</translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation>Stocker les paramètres au format INI dans le fichier indiqué. </translation>
    </message>
    <message>
        <source>file</source>
        <translation>fichier</translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation>Ne pas créer de sauvegarde automatique des données horaires. </translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation>Fichier à utiliser pour les données horaires.</translation>
    </message>
</context>
</TS>
